Animation class

Constructors

Animation({required String name, int? frameCount, double? frameDuration, required int frameWidth, required int frameHeight, int startRow = 0, int? maxColumns, bool loop = true, String? sheetKey, String? nextAnimation, int paddingX = 0, int paddingY = 0, int offsetX = 0, int offsetY = 0})

Properties

frameCount int?
getter/setter pair
frameDuration double?
getter/setter pair
frameHeight int
getter/setter pair
frameWidth int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loop bool
getter/setter pair
maxColumns int?
getter/setter pair
name String
getter/setter pair
nextAnimation String?
getter/setter pair
offsetX int
getter/setter pair
offsetY int
getter/setter pair
paddingX int
getter/setter pair
paddingY int
getter/setter pair
realFrameDuration double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sheetKey String?
getter/setter pair
startRow int
getter/setter pair

Methods

getFrameCount(int textureWidth, int textureHeight) int
getFrameRect(int frameIndex) RectangleD
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited