AppSystemCloner<T extends App<T>> class
A Cloner scoped to AppSystem cloning operations.
Methods
-
allow(CloneKind kind, {ECSBase<T>? owner, Object? payload})
→ bool
-
Delegates to policy with the given
kind, owner, and payload.
inherited
-
allowAppSystem(App<T> owner, AppSystem<T> appSystem)
→ bool
-
Whether
appSystem should be included in the clone of owner.
inherited
-
allowComp(IsComponentManagable<T, ECSBase<T>> owner, Comp<T> comp)
→ bool
-
Whether
comp should be included in the clone of owner.
inherited
-
allowEntity(IsEntityManagable<T, ECSBase<T>, Entity<T>> owner, Entity<T> entity)
→ bool
-
Whether
entity should be included in the clone.
inherited
-
allowHook(ECSBase<T> owner, CloneHookType type)
→ bool
-
Whether the listener/s identified by
type should be copied to the clone.
inherited
-
allowScene(App<T> owner, Scene<T> scene)
→ bool
-
Whether
scene should be included in the clone of owner.
inherited
-
allowSceneSystem(Scene<T> owner, SceneSystem<T> sceneSystem)
→ bool
-
Whether
sceneSystem should be included in the clone of owner.
inherited
-
allowState(ECSBase<T> owner, CloneStateType type)
→ bool
-
Whether the state category identified by
type should be copied to the clone.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited