AssetManager class abstract

Implementers

Constructors

AssetManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
font(String id, {String? path, int fontSize = 32}) FontD
image(String id, {String? path}) ImageD
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
texture(String id, {String? path}) TextureD
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited