CStateMachineSnapshot<T extends App<T> > class
- Inheritance
-
- Object
- StateSnapshot<
T, CStateMachine< T> > - CompSnapshot<
T, CStateMachine< T> > - CStateMachineSnapshot
Constructors
Properties
-
componentSnapshots
↔ List<
AnyCompSnapshot< T> > -
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- onExtra ↔ SnapshotExtraPolicy
-
getter/setter pairinherited
- onMissing ↔ SnapshotMissingPolicy
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceId ↔ String
-
getter/setter pairinherited
Methods
-
createInstance(
T app) → CStateMachine< T> -
Bare instance.
override
-
listenShouldDeleteExtra(
bool fn(ECSBase< T> target)) → StateSnapshot<T, CStateMachine< T> > -
Registers
fnas a should-delete-extra listener.inherited -
listenShouldRecreateMissing(
bool fn(String sourceId)) → StateSnapshot< T, CStateMachine< T> > -
Registers
fnas a should-recreate-missing listener.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldDeleteExtra(
ECSBase< T> target) → bool -
Override to cancel the deletion of extra from within the class.
inherited
-
shouldRecreateMissing(
String sourceId) → bool -
Override to cancel the recreation of missing from within the class.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited