allowSceneSystem method
Whether sceneSystem should be included in the clone of owner.
Implementation
bool allowSceneSystem(Scene<T> owner, SceneSystem<T> sceneSystem)
=> allow(.sceneSystem, owner: owner, payload: sceneSystem);
Whether sceneSystem should be included in the clone of owner.
bool allowSceneSystem(Scene<T> owner, SceneSystem<T> sceneSystem)
=> allow(.sceneSystem, owner: owner, payload: sceneSystem);