CollisionBackend class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
circleRectangle(
Vector2D center, num radius, RectangleD rec) → bool -
circles(
Vector2D center1, num radius1, Vector2D center2, num radius2) → bool -
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pointRectangle(
Vector2D point, RectangleD rec) → bool -
rectangles(
RectangleD rec1, RectangleD rec2) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited