onCollision method

void onCollision(
  1. ColliderCollision<T> collision
)

Called after onBeforeCollision passes but before the narrow phase determines whether the shapes actually overlap.

In most cases you want onAfterCollision instead.

There is no guarantee the shapes are touching when this is called.

Implementation

void onCollision(ColliderCollision<T> collision) {}