ComponentDrawer<T extends App<T>> class

Inheritance

Constructors

ComponentDrawer(T app)

Properties

app → T
finalinherited
backend UnhingedBackend
Shorthand for App.backend.
no setterinherited
draw Drawers<T>
Shorthand for App.draw.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
input InputSystem<T>
Shorthand for App.input.
no setterinherited
renderer Renderer<T>
Shorthand for App.renderer.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scene Scene<T>
Shorthand for App.currentScene.
no setterinherited
screenHeight double
Shorthand for App's height.
no setterinherited
screenSize Vector2D
Shorthand for App.screenSize.
no setterinherited
screenWidth double
Shorthand for App's width.
no setterinherited
time AppTime<T>
Shorthand for App.time.
no setterinherited

Methods

entityTree(Entity<T> entity, num x, num y, num fontSize, {ColorD? color, String? prefix}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tree(Comp<T> node, num x, num y, num fontSize, String prefix, ColorD color, [List<int>? yRef]) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited