DigitalDrawer<T extends App<T>> class

Inheritance

Constructors

DigitalDrawer(T app)

Properties

app → T
finalinherited
backend UnhingedBackend
Shorthand for App.backend.
no setterinherited
draw Drawers<T>
Shorthand for App.draw.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
input InputSystem<T>
Shorthand for App.input.
no setterinherited
renderer Renderer<T>
Shorthand for App.renderer.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scene Scene<T>
Shorthand for App.currentScene.
no setterinherited
screenHeight double
Shorthand for App's height.
no setterinherited
screenSize Vector2D
Shorthand for App.screenSize.
no setterinherited
screenWidth double
Shorthand for App's width.
no setterinherited
time AppTime<T>
Shorthand for App.time.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
number(RectangleD dst, String n, ColorD? backgroundColor, ColorD dimColor, ColorD litColor, {DigitalStyle style = .DEFAULT}) → void
Draws a single hex digit (0–9, A–F) as a 7-segment display inside dst.
text(num x, num y, num digitWidth, num digitHeight, String text, ColorD? digitBackgroundColor, ColorD digitUnlitSegmentsColor, ColorD digitLitSegmentsColor, {DigitalStyle style = .DEFAULT, num digitPadding = 1, ColorD? textBackgroundColor}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited