setLink method
Links this event to link so that stopping propagation on one
(via stopPropagation) also stops the other.
Implementation
void setLink(Event<T> link) => _linkedEvent = link;
Links this event to link so that stopping propagation on one
(via stopPropagation) also stops the other.
void setLink(Event<T> link) => _linkedEvent = link;