FAnimationController class

Constructors

FAnimationController({required double duration, void onComplete()?, void onFrame(double value, double elapsed)?})

Properties

duration double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onComplete ↔ void Function()?
getter/setter pair
onFrame ↔ void Function(double value, double elapsed)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
getter/setter pair

Methods

forward() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop() → void
toString() String
A string representation of this object.
inherited
update(double dt) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited