InputBackend class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
getCharPressed(
) → int -
getKeyPressed(
) → int -
isKeyDown(
KeyboardKey key) → bool -
isKeyPressed(
KeyboardKey key) → bool -
isKeyPressedRepeat(
KeyboardKey key) → bool -
isKeyUp(
KeyboardKey key) → bool -
isMouseButtonDown(
MouseButton button) → bool -
isMouseButtonPressed(
MouseButton button) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited