setActive method
Sets the active state to active and fires the activation hook.
Implementation
@mustCallSuper
E setActive(bool active) {
_active = active;
_doOnActivate();
return self;
}
Sets the active state to active and fires the activation hook.
@mustCallSuper
E setActive(bool active) {
_active = active;
_doOnActivate();
return self;
}