toggleActive method
- @mustCallSuper
Toggles the active state and fires the activation hook.
Implementation
@mustCallSuper
E toggleActive() {
_active = !_active;
_doOnActivate();
return self;
}
Toggles the active state and fires the activation hook.
@mustCallSuper
E toggleActive() {
_active = !_active;
_doOnActivate();
return self;
}