onAppSystemAdd method
Override to react when a system add is about to complete.
Called by the host after all before-checks have passed.
Implementation
void onAppSystemAdd(AppSystem<T> system) {}
Override to react when a system add is about to complete.
Called by the host after all before-checks have passed.
void onAppSystemAdd(AppSystem<T> system) {}