onAppSystemRemove method
Override to react when a system remove is about to complete.
Called by the host after all before-checks have passed.
Implementation
void onAppSystemRemove(AppSystem<T> system) {}
Override to react when a system remove is about to complete.
Called by the host after all before-checks have passed.
void onAppSystemRemove(AppSystem<T> system) {}