QueryCompDeep property
Returns a fresh QueryComponentComponentDeep that searches all descendant components recursively, including those on nested child components.
Implementation
QueryComponentComponentDeep<T> get QueryCompDeep => .new(app, this);
Returns a fresh QueryComponentComponentDeep that searches all descendant components recursively, including those on nested child components.
QueryComponentComponentDeep<T> get QueryCompDeep => .new(app, this);