containsComp<C extends Comp<T> > method
Whether a component of type C exists anywhere in this subtree.
Implementation
bool containsComp<C extends Comp<T>>() => findComp<C>() != null;
Whether a component of type C exists anywhere in this subtree.
bool containsComp<C extends Comp<T>>() => findComp<C>() != null;