onEntityAdd method
void
onEntityAdd(
- I entity
Override to react when an entity add is about to complete.
Called by the host after all before-checks have passed.
Implementation
void onEntityAdd(I entity) {}
Override to react when an entity add is about to complete.
Called by the host after all before-checks have passed.
void onEntityAdd(I entity) {}