onSceneAdd method
Override to react when a scene add is about to complete.
Called by the host after all before-checks have passed.
Implementation
void onSceneAdd(Scene<T> scene) {}
Override to react when a scene add is about to complete.
Called by the host after all before-checks have passed.
void onSceneAdd(Scene<T> scene) {}