hasSystem<S extends SceneSystem<T> > method
Returns true if a system of type S is currently registered.
Implementation
bool hasSystem<S extends SceneSystem<T>>() => _systems.any((s) => s is S);
Returns true if a system of type S is currently registered.
bool hasSystem<S extends SceneSystem<T>>() => _systems.any((s) => s is S);