onEvent method
Override to handle incoming events within the class.
Called after all registered listenOnEvent listeners, and only if propagation has not been stopped.
Implementation
void onEvent(Event<T> event) {}
Override to handle incoming events within the class.
Called after all registered listenOnEvent listeners, and only if propagation has not been stopped.
void onEvent(Event<T> event) {}