From method

Q From(
  1. List<E> entities
)

Query-like Restricts the query to a specific list of entities instead of the default queryableList.

Useful when you already have a pre-filtered subset and want to apply further conditions on top of it.

Implementation

Q From(List<E> entities) {
  _sourceList = entities;
  return self;
}