Where method
Query-like Keeps only elements for which fn returns true.
Use this for arbitrary conditions that don't map to a component check.
Implementation
Q Where(bool Function(E entity) fn) {
_groups.last.add(fn);
return self;
}
Query-like Keeps only elements for which fn returns true.
Use this for arbitrary conditions that don't map to a component check.
Q Where(bool Function(E entity) fn) {
_groups.last.add(fn);
return self;
}