RaylibAssetManager class

Inheritance

Constructors

RaylibAssetManager(Raylib rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
rl Raylib
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
font(String id, {String? path, int fontSize = 32}) FontD
override
image(String id, {String? path}) ImageD
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
texture(String id, {String? path}) TextureD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited