RaylibBackend class
- Inheritance
-
- Object
- UnhingedBackend
- RaylibBackend
Constructors
- RaylibBackend(Raylib rl, {RaylibRenderBackend? render, RaylibInputBackend? input, RaylibCollisionBackend? collision, RaylibAssetManager? assets})
Properties
- assets → AssetManager
-
finalinherited
- collision → CollisionBackend
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → InputBackend
-
finalinherited
-
mouse
↔ MouseInfo<
Vector2D> -
getter/setter pairinherited
- render → RenderBackend
-
finalinherited
- rl → Raylib
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginFrame(
) → void -
override
-
dispose(
) → void -
override
-
endFrame(
) → void -
inherited
-
getClipboardText(
) → String -
override
-
getFontDefault(
) → FontD -
override
-
getFrameTime(
) → double -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setClipboardText(
String text) → void -
override
-
setMouseCursor(
MouseCursor cursor) → void -
override
-
setTargetFPS(
int fps) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited