RaylibCollisionBackend class

Inheritance

Constructors

RaylibCollisionBackend(Raylib rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
rl Raylib
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

circleRectangle(Vector2D center, num radius, RectangleD rec) bool
override
circles(Vector2D center1, num radius1, Vector2D center2, num radius2) bool
override
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointRectangle(Vector2D point, RectangleD rec) bool
override
rectangles(RectangleD rec1, RectangleD rec2) bool
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited