RaylibInputBackend class

Inheritance

Constructors

RaylibInputBackend(Raylib rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
rl Raylib
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
inherited
getCharPressed() int
override
getKeyPressed() int
override
isKeyDown(KeyboardKey key) bool
override
isKeyPressed(KeyboardKey key) bool
override
isKeyPressedRepeat(KeyboardKey key) bool
override
isKeyUp(KeyboardKey key) bool
override
isMouseButtonDown(MouseButton button) bool
override
isMouseButtonPressed(MouseButton button) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited