RenderBackend class abstract

Implementers

Constructors

RenderBackend()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginDrawing() → void
beginScissorMode(num x, num y, num width, num height) → void
clearBackground(ColorD color) → void
dispose() → void
drawCircle(num centerX, num centerY, num radius, ColorD color) → void
drawCircleLinesV(Vector2D center, num radius, ColorD color) → void
drawLineEx(Vector2D startPos, Vector2D endPos, num thick, ColorD color) → void
drawPixel(num posX, num posY, ColorD color) → void
drawRectangle(num posX, num posY, num width, num height, ColorD color) → void
drawRectangleLinesEx(RectangleD rec, num lineThick, ColorD color) → void
drawRectangleLinesRotated(RectangleD rect, num rotationDegrees, num lineThick, ColorD color) → void
drawRectanglePro(RectangleD rec, Vector2D origin, num rotation, ColorD color) → void
drawRectangleRec(RectangleD rec, ColorD color) → void
drawRectangleRounded(RectangleD rec, num roundness, num segments, ColorD color) → void
drawRectangleRoundedLinesEx(RectangleD rec, num roundness, num segments, num lineThick, ColorD color) → void
drawText(String text, num posX, num posY, num fontSize, ColorD color) → void
drawTextEx(FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint) → void
drawTextPro(FontD font, String text, Vector2D position, Vector2D origin, num rotation, num fontSize, num spacing, ColorD tint) → void
drawTexturePro(TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, num rotation, ColorD tint) → void
drawTriangle(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color) → void
endDrawing() → void
endScissorMode() → void
measureText(String text, num fontSize) int
measureTextEx(FontD font, String text, num fontSize, num spacing) Vector2D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited