UnhingedBackend class abstract

Implementers

Constructors

UnhingedBackend({required RenderBackend render, required InputBackend input, required CollisionBackend collision, required AssetManager assets})

Properties

assets AssetManager
final
collision CollisionBackend
final
hashCode int
The hash code for this object.
no setterinherited
input InputBackend
final
mouse MouseInfo<Vector2D>
getter/setter pair
render RenderBackend
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginFrame() → void
dispose() → void
endFrame() → void
getClipboardText() String
getFontDefault() FontD
getFrameTime() double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setClipboardText(String text) → void
setMouseCursor(MouseCursor cursor) → void
setTargetFPS(int fps) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited