UnhingedRaylibGame<T extends App<T>> class abstract

Inheritance

Constructors

UnhingedRaylibGame()

Properties

app ↔ T
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close(Raylib rl) → void
Called once after shouldClose returns true.
override
create(RaylibBackend backend) → T
dispose(Raylib rl) → void
Called after close to release any remaining Dart-side resources.
override
init(Raylib rl) → void
Called once before the game loop starts.
override
loop(Raylib rl) → void
Called once per frame while shouldClose returns false.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldClose(Raylib rl) bool
Returns true when the game loop should stop.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited