init method
Called once before the game loop starts.
Use this to initialize game state and open the window via RaylibCoreModuleBase.InitWindow.
Implementation
@override
void init(Raylib rl) => app = create(.new(rl))..init();
Called once before the game loop starts.
Use this to initialize game state and open the window via RaylibCoreModuleBase.InitWindow.
@override
void init(Raylib rl) => app = create(.new(rl))..init();