AllowAllPolicy<T extends App<T> > class
A ClonePolicy that allows everything except CloneStateType.identity.
Identity fields (ECSBase.id, ECSBase.namedId, ECSBase.name) are always excluded so that clones receive their own auto-assigned identity rather than sharing the origin's.
- Implemented types
-
- ClonePolicy<
T>
- ClonePolicy<
Constructors
- AllowAllPolicy()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allow(
CloneKind kind, {ECSBase< T> ? owner, Object? payload}) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited