DigitalStyle class
Constructors
- DigitalStyle({double segmentThickness = 0.13, double segmentSpacing = 0, bool roundedEnds = false, double roundness = 0.4})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- roundedEnds → bool
-
If true, segments are drawn with rounded ends (DrawRectangleRounded).
If false, plain rectangles are used.
final
- roundness → double
-
Roundness factor used when roundedEnds is true. Range 0.0–1.0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentSpacing → double
-
Fraction of thickness; controls tip gaps.
final
- segmentThickness → double
-
Segment thickness as a fraction of the digit width.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- DEFAULT → const DigitalStyle
- ROUNDED → const DigitalStyle
- THICK → const DigitalStyle
- THIN → const DigitalStyle