EventScope enum
Controls how far an Event propagates through the ECS hierarchy once dispatched or emitted.
Ordered loosely from widest reach (global) to narrowest (self).
Values
- global → const EventScope
-
App + AppSystems + Scene + SceneSystems + Entities + Components
- globalNoEntities → const EventScope
-
App + AppSystems + Scene + SceneSystems (no entities/components)
- scene → const EventScope
-
Scene + SceneSystems + Entities + Components
- sceneOnly → const EventScope
-
Scene + SceneSystems only (no entities/components)
- local → const EventScope
-
Just the emitter and it's children rules: App > App, AppSystems AppSystem > AppSystem Scene > Scene, SceneSystem SceneSystem > SceneSystem Entity > Entity, all Components (even nested) Component > Component, all Components (even nested)
- self → const EventScope
-
Just the emitter, no propagation at all
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - next → EventScope
-
Gets the next entry.
no setter
- prev → EventScope
-
Gets the previous entry.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EventScope> - A constant List of the values in this enum, in order of their declaration.