IntervalTask<T extends App<T> > class
Constructors
-
IntervalTask(T app, {double? remaining, double interval = 0, int? frameInterval, bool triggerImmediately = false, required void actionUpdate(IntervalTask<
T> self, double elapsed), void actionFinish(IntervalTask<T> self)?})
Properties
-
actionFinish
→ void Function(IntervalTask<
T> self)? -
final
-
actionUpdate
→ void Function(IntervalTask<
T> self, double elapsed) -
final
- app → T
-
finalinherited
- backend → UnhingedBackend
-
Shorthand for App.backend.
no setterinherited
-
draw
→ Drawers<
T> -
Shorthand for App.draw.
no setterinherited
- frameInterval → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Per-type unique identifier, auto-assigned in the constructor.
no setterinherited
-
input
→ InputSystem<
T> -
Shorthand for App.input.
no setterinherited
- interval → double
-
final
- isCanceled → bool
-
Whether this object has been canceled.
no setterinherited
- name ↔ String
-
Human-readable name, defaults to
<runtimeType>_<id>.getter/setter pairinherited - namedId → String
-
Per-type unique String identifier, auto-assigned in the constructor.
Defaults to
<runtimeType>_<id>.no setterinherited -
parent
↔ ECSBase<
T> ? -
The parent object in the ECS tree, if any.
getter/setter pairinherited
- remaining ↔ double?
-
getter/setter pair
-
renderer
→ Renderer<
T> -
Shorthand for App.renderer.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scene
→ Scene<
T> -
Shorthand for App.currentScene.
no setterinherited
- sceneBounds → Bounds
-
no setterinherited
- sceneHeight → double
-
no setterinherited
- sceneSize → Vector2D
-
no setterinherited
- sceneWidth → double
-
no setterinherited
- screenHeight → double
-
Shorthand for App's height.
no setterinherited
- screenSize → Vector2D
-
Shorthand for App.screenSize.
no setterinherited
- screenWidth → double
-
Shorthand for App's width.
no setterinherited
-
self
→ Task<
T> -
This object cast to
T.no setterinherited -
time
→ AppTime<
T> -
Shorthand for App.time.
no setterinherited
- triggerImmediately → bool
-
final
Methods
-
callback(
void callback()) → void -
inherited
-
cancel(
) → bool -
Attempts to cancel this object.
inherited
-
getAncestors(
) → Iterable< ECSBase< T> > -
Returns every ancestor of this component, from immediate parent up to the root.
inherited
-
getDepth(
) → int -
Returns the depth/level in the hierarchy.
inherited
-
getParentAs<
P extends ECSBase< (T> >) → P? -
Returns parent cast to
P, ornullif the cast would fail.inherited -
getPath(
) → List< ECSBase< T> > -
Returns the path from the root down to this one, inclusive.
inherited
-
hasParentOf<
P extends ECSBase< (T> >) → bool -
Whether parent is of type
P.inherited -
listenOnAfterCancel(
void fn(Task< T> self)) → Task<T> -
Registers
fnas an after-cancel listener.inherited -
listenOnBeforeCancel(
bool fn(Task< T> self)) → Task<T> -
Registers
fnas a before-cancel listener.inherited -
listenOnCancel(
void fn(Task< T> self)) → Task<T> -
Registers
fnas a cancel listener.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAfterCancel(
) → void -
Override to react after the cancel has completed.
inherited
-
onBeforeCancel(
) → bool -
Override to cancel the cancel from within the class.
inherited
-
onCancel(
) → void -
Override to react when the cancel is about to complete.
inherited
-
onSelf(
void fn(Task< T> self)) → Task<T> -
Calls
fnwith self and returns self, for fluent chaining.inherited -
run(
Task< T> task) → void -
inherited
-
task(
Task< T> task) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uniqKey(
String key) → String -
Returns a key namespaced to this object's namedId.
inherited
-
update(
double dt) → bool -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited