WithWhere<C extends Comp<T> > method
Query-like Keeps only elements that have C and for which fn
returns true given the entity and its C instance.
Implementation
Q WithWhere<C extends Comp<T>>(
bool Function(E entity, C c) fn
) {
_groups.last.add((e) {
final c = e.get<C>();
return c != null && fn(e, c);
});
return self;
}