QueryGroup<T extends App<T> , E extends IsComponentManagable<T, E> > class
A single clause group in a query expression.
Each group holds a list of QueryFilterFn predicates that must all pass for an
entity to be accepted (AND semantics within the group). When negated is
true, the combined result of the group is inverted, i.e. an entity passes
only if it would not have passed all the filters.
Groups are created implicitly by QueryComponentManagable.Or and QueryComponentManagable.Not; you rarely construct one directly.
Constructors
Properties
-
filters
→ List<
QueryFilterFn< T, E> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- negated ↔ bool
-
When
true, the entire group's result is negated before being applied.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
QueryFilterFn< T, E> f) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited