RaylibRenderBackend class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
rl
→ Raylib
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginDrawing()
→ void
-
override
-
beginScissorMode(num x, num y, num width, num height)
→ void
-
override
-
clearBackground(ColorD color)
→ void
-
override
-
dispose()
→ void
-
inherited
-
drawCircle(num centerX, num centerY, num radius, ColorD color)
→ void
-
override
-
drawCircleLinesV(Vector2D center, num radius, ColorD color)
→ void
-
override
-
drawLineEx(Vector2D startPos, Vector2D endPos, num thick, ColorD color)
→ void
-
override
-
drawPixel(num posX, num posY, ColorD color)
→ void
-
override
-
drawRectangle(num posX, num posY, num width, num height, ColorD color)
→ void
-
override
-
drawRectangleLinesEx(RectangleD rec, num lineThick, ColorD color)
→ void
-
override
-
drawRectangleLinesRotated(RectangleD rect, num rotationDegrees, num lineThick, ColorD color)
→ void
-
override
-
drawRectanglePro(RectangleD rec, Vector2D origin, num rotation, ColorD color)
→ void
-
override
-
drawRectangleRec(RectangleD rec, ColorD color)
→ void
-
override
-
drawRectangleRounded(RectangleD rec, num roundness, num segments, ColorD color)
→ void
-
override
-
drawRectangleRoundedLinesEx(RectangleD rec, num roundness, num segments, num lineThick, ColorD color)
→ void
-
override
-
drawText(String text, num posX, num posY, num fontSize, ColorD color)
→ void
-
override
-
drawTextEx(FontD font, String text, Vector2D position, num fontSize, num spacing, ColorD tint)
→ void
-
override
-
drawTextPro(FontD font, String text, Vector2D position, Vector2D origin, num rotation, num fontSize, num spacing, ColorD tint)
→ void
-
override
-
drawTexturePro(TextureD texture, RectangleD source, RectangleD dest, Vector2D origin, num rotation, ColorD tint)
→ void
-
override
-
drawTriangle(Vector2D v1, Vector2D v2, Vector2D v3, ColorD color)
→ void
-
override
-
endDrawing()
→ void
-
override
-
endScissorMode()
→ void
-
override
-
measureText(String text, num fontSize)
→ int
-
override
-
measureTextEx(FontD font, String text, num fontSize, num spacing)
→ Vector2D
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited