SentenceDrawer<T extends App<T> > class
Constructors
-
SentenceDrawer(TextDrawer<
T> _parent)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
flush(
{TextDrawerHAlign halign = .left, TextDrawerVAlign valign = .top}) → TextDrawer< T> - Draws the buffered segments aligned relative to the parent's current cursor, then advances the parent past the sentence.
-
gap(
[double? amount]) → SentenceDrawer< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
text(
String content, [ColorD? color]) → SentenceDrawer< T> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited