SpatialGrid<T extends App<T> > class
Constructors
- SpatialGrid(double cellSize)
Properties
Methods
-
clear(
) → void - Clear all cells (call once per frame)
-
clone(
) → SpatialGrid< T> -
insert(
Entity< T> entity, CCollider<T> collider) → void - Insert an entity into all cells its collider overlaps
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
CCollider< T> collider) → List<Entity< T> > - Query all entities near a collider (returns candidates for collision check)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited