TextDrawer<T extends App<T> > class
- Inheritance
-
- Object
- BaseDrawer<
T> - TextDrawer
Constructors
- TextDrawer(T app)
Properties
- app → T
-
finalinherited
- backend → UnhingedBackend
-
Shorthand for App.backend.
no setterinherited
-
draw
→ Drawers<
T> -
Shorthand for App.draw.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ InputSystem<
T> -
Shorthand for App.input.
no setterinherited
-
renderer
→ Renderer<
T> -
Shorthand for App.renderer.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scene
→ Scene<
T> -
Shorthand for App.currentScene.
no setterinherited
- screenHeight → double
-
Shorthand for App's height.
no setterinherited
- screenSize → Vector2D
-
Shorthand for App.screenSize.
no setterinherited
- screenWidth → double
-
Shorthand for App's width.
no setterinherited
-
time
→ AppTime<
T> -
Shorthand for App.time.
no setterinherited
Methods
-
align(
TextDrawerHAlign halign, TextDrawerVAlign valign) → TextDrawer< App> -
at(
num x, num y) → TextDrawer< App> - Jump the cursor to an arbitrary position (e.g. start of a new block).
-
fontSize(
num fontSize) → TextDrawer< App> -
gap(
[num? amount]) → TextDrawer< App> - Adds extra horizontal gap without drawing anything.
-
halign(
TextDrawerHAlign align) → TextDrawer< App> -
lineHeight(
num lineHeight) → TextDrawer< App> -
nl(
) → TextDrawer< App> - Moves cursor back to start x, down by one line.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
position(
num x, num y) → TextDrawer< App> -
sentence(
) → SentenceDrawer< T> -
text(
String content, [ColorD? color]) → TextDrawer< App> -
Draws
contentat the current cursor and advances horizontally. -
toString(
) → String -
A string representation of this object.
inherited
-
valign(
TextDrawerVAlign align) → TextDrawer< App> -
wordSpacing(
num wordSpacing) → TextDrawer< App>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited